# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Version information is in version.hpp
%global beta 1
%global actualversion 7.11
%global tarballversion 7.1.5
%global rpmrel 1.0.cf

Summary:	Extract, test and view RAR archives
Name:		unrar
Version:	%{actualversion}
Release:	%{?beta:0.}%{rpmrel}%{?beta:.beta%{beta}}.%{__distinit}%{__distvers}
License:	Freeware with further limitations
URL:		http://www.rarlab.com/rar_archiver.htm
Source0:	http://www.rarlab.com/rar/unrarsrc-%{tarballversion}.tar.gz
Source1:	http://ftp.de.debian.org/debian/pool/non-free/u/unrar-nonfree/unrar-nonfree_7.1.4-2.debian.tar.xz
Patch0:		unrar-7.10-build.patch
BuildRequires:	coreutils
BuildRequires:	gcc-c++
BuildRequires:	make
BuildRequires:	sed

%description
The unRAR utility is a freeware program, distributed with source code and
developed for extracting, testing and viewing the contents of archives created
with the RAR archiver version 1.50 and above.

%package -n libunrar
Summary:	Decompress library for RAR archives

# Packages using libunrar must add an explicit versioned dependency:
#{?unrar_version:Requires: libunrar%%{_isa} = %%{unrar_version}}

%description -n libunrar
The libunrar library allows programs linking against it to decompress
existing RAR archives.

%package -n libunrar-devel
Summary:	Development files for libunrar
Requires:	libunrar = %{version}-%{release}
Provides:	libunrar3-%{version} = %{version}-%{release}

%description -n libunrar-devel
The libunrar-devel package contains libraries and header files for
developing applications that use libunrar.

%prep
%setup -q -n %{name} -a 1

# Show version information as it's not always obvious
cat version.hpp

# Use distribution build flags
%patch -P 0 -p1

# Fix line endings
sed -i -e 's/\r$//' readme.txt

%build
# TODO: build the library first and then build the binary against it

# Build the binary
make %{?_smp_mflags} \
	CXX="%{__cxx}" \
	CXXFLAGS="%{optflags} -fPIC -DPIC" \
	LDFLAGS="%{?__global_ldflags} -pthread" \
	STRIP=:

# Build the library
make %{?_smp_mflags} lib \
	CXX="%{__cxx}" \
	CXXFLAGS="%{optflags} -fPIC -DPIC" \
	LDFLAGS="%{?__global_ldflags} -pthread" \
	STRIP=:

%install
install -D -m 755 unrar %{buildroot}%{_bindir}/unrar
install -D -m 644 -p debian/unrar-nonfree.1 %{buildroot}%{_mandir}/man1/unrar.1
install -D -m 755 libunrar.so %{buildroot}%{_libdir}/libunrar.so
mkdir -p -m 755 %{buildroot}%{_includedir}/unrar/
for header in *.hpp; do
	install -D -p -m 644 $header %{buildroot}%{_includedir}/unrar/$header
done

# RPM Macros support
mkdir -p %{buildroot}%{_sysconfdir}/rpm
cat > %{buildroot}%{_sysconfdir}/rpm/macros.unrar << EOF
# unrar RPM Macros
%unrar_version	%{version}
EOF
touch -r license.txt %{buildroot}%{_sysconfdir}/rpm/macros.unrar

%files
%license license.txt
%doc readme.txt
%{_bindir}/unrar
%{_mandir}/man1/unrar.1.gz

%files -n libunrar
%license license.txt
%doc readme.txt
%{_libdir}/libunrar.so

%files -n libunrar-devel
%config %{_sysconfdir}/rpm/macros.unrar
%{_includedir}/unrar/

%changelog
* Wed Feb 26 2025 Paul Howarth <paul@city-fan.org> - 7.11-0.1.0.cf.beta1
- Update to 7.11 beta 1

* Wed Feb 19 2025 Paul Howarth <paul@city-fan.org> - 7.10-1.0.cf
- Update to 7.10
- Update debian files to 7.1.4-1

* Tue Jan 21 2025 Paul Howarth <paul@city-fan.org> - 7.10-0.1.0.cf.beta3
- Update to 7.10 beta 3
- Update debian files to 7.1.3-1

* Thu Dec  5 2024 Paul Howarth <paul@city-fan.org> - 7.10-0.1.0.cf.beta2
- Update to 7.10 beta 2
- Update debian files to 7.1.1-1

* Thu Nov  7 2024 Paul Howarth <paul@city-fan.org> - 7.10-0.1.0.cf.beta1
- Update to 7.10 beta 1

* Thu May 16 2024 Paul Howarth <paul@city-fan.org> - 7.01-1.0.cf
- Update to 7.01
- Update debian files to 7.0.9-1

* Fri Apr 26 2024 Paul Howarth <paul@city-fan.org> - 7.01-0.1.0.cf.beta1
- Update to 7.01 beta 1
- Update debian files to 7.0.8-1

* Thu Feb 29 2024 Paul Howarth <paul@city-fan.org> - 7.00-1.0.cf
- Update to 7.00
- Update debian files to 7.0.6-1
- Drop support for Fedora < 29

* Wed Jan 24 2024 Paul Howarth <paul@city-fan.org> - 7.00-0.6.0.cf.beta4
- Update to 7.00 beta 4

* Thu Nov 30 2023 Paul Howarth <paul@city-fan.org> - 7.00-0.5.0.cf.beta3
- Update to 7.00 beta 3
- Update debian files to 7.0.5-1

* Thu Nov 30 2023 Paul Howarth <paul@city-fan.org> - 7.00-0.4.0.cf.beta2
- Update to 7.00 beta 2
- Update debian files to 7.0.4-1

* Thu Nov  9 2023 Paul Howarth <paul@city-fan.org> - 7.00-0.3.0.cf.beta1
- Updated source to 7.0.3, still 7.00 beta 1
- Update debian files to 7.0.3-1

* Fri Oct 27 2023 Paul Howarth <paul@city-fan.org> - 7.00-0.2.0.cf.beta1
- Updated source to 7.0.2, still 7.00 beta 1
- Update debian files to 7.0.2-1

* Mon Oct 23 2023 Paul Howarth <paul@city-fan.org> - 7.00-0.1.0.cf.beta1
- Update to 7.00 beta 1

* Fri Oct  6 2023 Paul Howarth <paul@city-fan.org> - 6.24-1.0.cf
- Update to 6.24
- Update debian files to 6.2.12-1

* Tue Sep 19 2023 Paul Howarth <paul@city-fan.org> - 6.24-0.1.0.cf.beta1
- Update to 6.24 beta 1
- Update debian files to 6.2.10-2

* Wed Aug  2 2023 Paul Howarth <paul@city-fan.org> - 6.23-1.0.cf
- Update to 6.23
- Update debian files to 6.2.9-1

* Thu Jul 20 2023 Paul Howarth <paul@city-fan.org> - 6.23-0.1.0.cf.beta1
- Update to 6.23 beta 1

* Mon Jun  5 2023 Paul Howarth <paul@city-fan.org> - 6.22-1.0.cf
- Update to 6.22
- Update debian files to 6.2.8-1

* Mon May 15 2023 Paul Howarth <paul@city-fan.org> - 6.22-0.1.0.cf.beta1
- Update to 6.22 beta 1
- Update debian files to 6.2.7-1
- Avoid use of deprecated patch syntax

* Mon Feb 20 2023 Paul Howarth <paul@city-fan.org> - 6.21-1.0.cf
- Update to 6.21

* Thu Jan 26 2023 Paul Howarth <paul@city-fan.org> - 6.21-0.1.0.cf.beta1
- Update to 6.21 beta 1
- Update debian files to 6.2.5-1

* Mon Jan 23 2023 Paul Howarth <paul@city-fan.org> - 6.20-1.0.cf
- Update to 6.20

* Sun Dec 18 2022 Paul Howarth <paul@city-fan.org> - 6.20-0.3.0.cf.beta3
- Update to 6.20 beta 3

* Mon Nov 14 2022 Paul Howarth <paul@city-fan.org> - 6.20-0.2.0.cf.beta2
- Update to 6.20 beta 2

* Wed Oct 26 2022 Paul Howarth <paul@city-fan.org> - 6.20-0.1.0.cf.beta1
- Update to 6.20 beta 1
- Update debian files to 6.1.7-4
- Explicitly use -std=c++11 prior to Fedora 27

* Sun May  8 2022 Paul Howarth <paul@city-fan.org> - 6.12-1.0.cf
- Update to 6.12

* Fri Mar  4 2022 Paul Howarth <paul@city-fan.org> - 6.11-1.0.cf
- Update to 6.11
- Update debian files to 6.1.5-1

* Wed Feb 23 2022 Paul Howarth <paul@city-fan.org> - 6.11-0.1.0.cf.beta1
- Update to 6.11 beta 1

* Mon Jan 24 2022 Paul Howarth <paul@city-fan.org> - 6.10-1.0.cf
- Update to 6.10
- Update debian files to 6.1.3-2

* Fri Dec 10 2021 Paul Howarth <paul@city-fan.org> - 6.10-0.1.0.cf.beta3
- Update to 6.10 beta 3
- Fix dist tags for CentOS Stream

* Tue Nov 16 2021 Paul Howarth <paul@city-fan.org> - 6.10-0.1.0.cf.beta2
- Update to 6.10 beta 2
- Update debian files to 6.0.7-6
- Fix dist tags for Alma and Rocky Linux

* Tue Jun 15 2021 Paul Howarth <paul@city-fan.org> - 6.02-1.0.cf
- Update to 6.02
- Update debian files to 6.0.7-1

* Mon May 17 2021 Paul Howarth <paul@city-fan.org> - 6.02-0.1.0.cf.beta1
- Update to 6.02 beta 1

* Mon Apr 12 2021 Paul Howarth <paul@city-fan.org> - 6.01-1.0.cf
- Update to 6.01

* Mon Mar  8 2021 Paul Howarth <paul@city-fan.org> - 6.01-0.1.0.cf.beta1
- Update to 6.01 beta 1
- Update debian files to 6.0.3-1
- Don't create versioned shared library, stick with upstream library name
- Drop patch for unresolved symbol issues
- Add rpm macro file so that dependent packages can add versioned dependency
- Use %%license unconditionally

* Mon Dec  7 2020 Paul Howarth <paul@city-fan.org> - 6.00-1.0.cf
- Update to 6.00

* Fri Nov 13 2020 Paul Howarth <paul@city-fan.org> - 6.00-0.1.0.cf.beta2
- Update to 6.00 beta 2
- Update debian files to 5.9.4-1

* Fri Oct 23 2020 Paul Howarth <paul@city-fan.org> - 6.00-0.1.0.cf.beta1
- Update to 6.00 beta 1

* Thu Jul  9 2020 Paul Howarth <paul@city-fan.org> - 5.91-2.0.cf
- Add patch to fix parallel build (https://bugs.gentoo.org/528218)

* Tue Jun 30 2020 Paul Howarth <paul@city-fan.org> - 5.91-1.0.cf
- Update to 5.91

* Fri Jun  5 2020 Paul Howarth <paul@city-fan.org> - 5.91-0.1.0.cf.beta1
- Update to 5.91 beta 1
- Drop parallel build, which does not work reliably

* Tue Mar 31 2020 Paul Howarth <paul@city-fan.org> - 5.90-1.0.cf
- Update to 5.90

* Wed Jan 29 2020 Paul Howarth <paul@city-fan.org> - 5.90-0.1.0.cf.beta1
- Update to 5.90 beta 1

* Wed Dec 11 2019 Paul Howarth <paul@city-fan.org> - 5.80-1.0.cf
- Update to 5.80

* Mon Nov 18 2019 Paul Howarth <paul@city-fan.org> - 5.80-0.2.0.cf.beta4
- Update to 5.80 beta 4

* Mon Oct 21 2019 Paul Howarth <paul@city-fan.org> - 5.80-0.2.0.cf.beta3
- Update to 5.80 beta 3

* Thu Sep 26 2019 Paul Howarth <paul@city-fan.org> - 5.80-0.2.0.cf.beta2
- Update to 5.80 beta 2

* Fri Sep  6 2019 Paul Howarth <paul@city-fan.org> - 5.80-0.2.0.cf.beta1
- Remove pointless alternatives setup for non-existent Fedora unrar package

* Fri Aug 30 2019 Paul Howarth <paul@city-fan.org> - 5.80-0.1.0.cf.beta1
- Update to 5.80 beta 1

* Mon Apr 29 2019 Paul Howarth <paul@city-fan.org> - 5.71-1.0.cf
- Update to 5.71

* Wed Apr  3 2019 Paul Howarth <paul@city-fan.org> - 5.71-0.1.0.cf.beta1
- Update to 5.71 beta 1
- Update debian files to 5.6.6-2

* Wed Feb 27 2019 Paul Howarth <paul@city-fan.org> - 5.70-1.0.cf
- Update to 5.70 final release

* Fri Feb 22 2019 Paul Howarth <paul@city-fan.org> - 5.70-0.1.0.cf.beta2
- Update to 5.70 beta 2

* Tue Feb 12 2019 Paul Howarth <paul@city-fan.org> - 5.70-0.1.0.cf.beta1
- Update to 5.70 beta 1
- Update debian files to 5.6.6-1
- Use %%{?__global_ldflags}

* Thu Oct  4 2018 Paul Howarth <paul@city-fan.org> - 5.61-1.0.cf
- Update to 5.61

* Tue Sep  4 2018 Paul Howarth <paul@city-fan.org> - 5.61-0.1.0.cf.beta1
- Update to 5.61 beta 1

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 5.60-1.0.cf
- Update to 5.60

* Mon May 14 2018 Paul Howarth <paul@city-fan.org> - 5.60-0.1.0.cf.beta4
- Update to 5.60 beta 4

* Tue Apr  3 2018 Paul Howarth <paul@city-fan.org> - 5.60-0.1.0.cf.beta2
- Update to 5.60 beta 2

* Mon Mar 12 2018 Paul Howarth <paul@city-fan.org> - 5.60-0.1.0.cf.beta1
- Update to 5.60 beta 1

* Fri Mar  9 2018 Paul Howarth <paul@city-fan.org> - 5.50-2.0.cf
- Update debian files to 5.5.8-1
- Drop ldconfig scriptlets (replaced by RPM File Triggers) from Fedora 28

* Mon Aug 14 2017 Paul Howarth <paul@city-fan.org> - 5.50-1.0.cf
- Update to 5.50

* Wed Jul 26 2017 Paul Howarth <paul@city-fan.org> - 5.50-0.6.0.cf.beta6
- Update to 5.50 beta 6
- Update debian files to 5.5.5-1

* Mon Jul  3 2017 Paul Howarth <paul@city-fan.org> - 5.50-0.5.0.cf.beta5
- Update to 5.50 beta 5

* Fri Jun 16 2017 Paul Howarth <paul@city-fan.org> - 5.50-0.4.0.cf.beta4
- Update to 5.50 beta 4

* Tue May  2 2017 Paul Howarth <paul@city-fan.org> - 5.50-0.3.0.cf.beta1
- New upstream tarball 5.5.3

* Tue Apr 25 2017 Paul Howarth <paul@city-fan.org> - 5.50-0.2.0.cf.beta1
- New upstream tarball 5.5.2

* Mon Apr 17 2017 Paul Howarth <paul@city-fan.org> - 5.50-0.1.0.cf.beta1
- Update to 5.50 beta 1
- Update debian files to 5.4.5-1
- Add patch to remove bit of code left over from upstream rar sources
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - No longer need to unpack debian files manually

* Tue Aug 16 2016 Paul Howarth <paul@city-fan.org> - 5.40-1.0.cf
- Update to 5.40

* Fri Jul 29 2016 Paul Howarth <paul@city-fan.org> - 5.40-0.2.0.cf.beta4
- New upstream tarball but same version number

* Fri Jul 22 2016 Paul Howarth <paul@city-fan.org> - 5.40-0.1.0.cf.beta4
- Update to 5.40 beta 4

* Tue May 31 2016 Paul Howarth <paul@city-fan.org> - 5.40-0.1.0.cf.beta2
- Update to 5.40 beta 2

* Mon Feb  8 2016 Paul Howarth <paul@city-fan.org> - 5.31-2.0.cf
- New upstream tarball but same version number

* Fri Feb  5 2016 Paul Howarth <paul@city-fan.org> - 5.31-1.0.cf
- Update to 5.31

* Sun Jan  3 2016 Paul Howarth <paul@city-fan.org> - 5.31-0.1.0.cf.beta1
- Update to 5.31 beta 1

* Wed Nov 25 2015 Paul Howarth <paul@city-fan.org> - 5.30-1.0.cf
- Update to 5.30
- Update debian files to 5.3.2-1

* Wed Oct 28 2015 Paul Howarth <paul@city-fan.org> - 5.30-0.2.0.cf.beta6
- Update to 5.30 beta 6

* Mon Oct 12 2015 Paul Howarth <paul@city-fan.org> - 5.30-0.2.0.cf.beta5
- Update to 5.30 beta 5

* Fri Oct  2 2015 Paul Howarth <paul@city-fan.org> - 5.30-0.2.0.cf.beta4
- New upstream tarball but same version number

* Mon Sep 14 2015 Paul Howarth <paul@city-fan.org> - 5.30-0.1.0.cf.beta4
- Update to 5.30 beta 4

* Tue Sep  1 2015 Paul Howarth <paul@city-fan.org> - 5.30-0.1.0.cf.beta3
- Update to 5.30 beta 3

* Wed Aug  5 2015 Paul Howarth <paul@city-fan.org> - 5.30-0.1.0.cf.beta2
- Update to 5.30 beta 2
- Update debian files to 5.2.7-0.1

* Mon Jul 20 2015 Paul Howarth <paul@city-fan.org> - 5.30-0.1.0.cf.beta1
- Update to 5.30 beta 1

* Thu Mar 26 2015 Paul Howarth <paul@city-fan.org> - 5.21-2.0.cf
- New upstream tarball but same version number

* Tue Feb 17 2015 Paul Howarth <paul@city-fan.org> - 5.21-1.0.cf
- Update to 5.21

* Mon Feb  2 2015 Paul Howarth <paul@city-fan.org> - 5.21-0.1.0.cf.beta2
- Update to 5.21 beta 2

* Mon Jan 12 2015 Paul Howarth <paul@city-fan.org> - 5.21-0.1.0.cf.beta1
- Update to 5.21 beta 1

* Wed Dec  3 2014 Paul Howarth <paul@city-fan.org> - 5.20-1.0.cf
- Update to 5.20

* Mon Nov  3 2014 Paul Howarth <paul@city-fan.org> - 5.20-0.1.0.cf.beta3
- Update to 5.20 beta 3

* Wed Oct 15 2014 Paul Howarth <paul@city-fan.org> - 5.20-0.1.0.cf.beta1
- Update to 5.20 beta 1

* Fri Aug 22 2014 Paul Howarth <paul@city-fan.org> - 5.11-0.1.0.cf.beta1
- Update to 5.11 beta 1
- Use %%license where possible

* Thu Jun 12 2014 Paul Howarth <paul@city-fan.org> - 5.10-1.0.cf
- Update to 5.10

* Tue May  6 2014 Paul Howarth <paul@city-fan.org> - 5.10-0.1.0.cf.beta4
- Update to 5.10 beta 4

* Wed Apr 30 2014 Paul Howarth <paul@city-fan.org> - 5.10-0.1.0.cf.beta3
- Update to 5.10 beta 3
- Drop %%defattr, redundant since rpm 4.4

* Mon Apr  7 2014 Paul Howarth <paul@city-fan.org> - 5.10-0.1.0.cf.beta2
- Update to 5.10 beta 2

* Tue Mar 18 2014 Paul Howarth <paul@city-fan.org> - 5.10-0.1.0.cf.beta1
- Update to 5.10 beta 1
- Update debian patch to 5.0.10-1

* Tue Dec  3 2013 Paul Howarth <paul@city-fan.org> - 5.01-1.0.cf
- Update to 5.01

* Tue Nov 12 2013 Paul Howarth <paul@city-fan.org> - 5.01-0.1.0.cf.beta1
- Update to 5.01 beta 1

* Mon Oct 28 2013 Paul Howarth <paul@city-fan.org> - 5.00-3.0.cf
- Remove unrar-4.2.3-fix-build.patch and add clean step to %%build
  (RPM Fusion #2869)

* Wed Sep 25 2013 Paul Howarth <paul@city-fan.org> - 5.00-2.0.cf
- Update to 5.0.12 tarball

* Wed Sep  4 2013 Paul Howarth <paul@city-fan.org> - 5.00-1.0.cf
- Update to 5.00

* Mon Aug  5 2013 Paul Howarth <paul@city-fan.org> - 5.00-0.8.0.cf.beta8
- Update to 5.00 beta 8

* Mon Jul 15 2013 Paul Howarth <paul@city-fan.org> - 5.00-0.7.0.cf.beta7
- Update to 5.00 beta 7

* Thu Jun 20 2013 Paul Howarth <paul@city-fan.org> - 5.00-0.6.1.cf.beta6
- Update to 5.00 beta 6

* Wed Jun 12 2013 Paul Howarth <paul@city-fan.org> - 5.00-0.6.0.cf.beta5
- Still beta5, upstream's numbering scheme is messy

* Tue May 28 2013 Paul Howarth <paul@city-fan.org> - 5.00-0.5.0.cf.beta5
- Update to 5.00 beta 5

* Tue May 21 2013 Paul Howarth <paul@city-fan.org> - 5.00-0.4.0.cf.beta4
- Update to 5.00 beta 4

* Fri May 10 2013 Paul Howarth <paul@city-fan.org> - 5.00-0.3.0.cf.beta3
- Update to 5.00 beta 3

* Wed May  1 2013 Paul Howarth <paul@city-fan.org> - 5.00-0.2.0.cf.beta2
- Update to 5.00 beta 2

* Tue Apr 30 2013 Paul Howarth <paul@city-fan.org> - 5.00-0.1.0.cf.beta1
- Update to 5.00 beta 1
- Update patches to apply to new makefile

* Fri Jun 15 2012 Paul Howarth <paul@city-fan.org> - 4.20-1.0.cf
- Update to 4.20 final
  - RAR general decompression algorithm speed is slightly improved, though not
    to the same extent as RAR compression; RAR decompression is not able to use
    several processor cores, so its performance does not depend on a number of
    cores
- Tidy up build process and generate PIC code
- Include all header files in the -devel package (RPM Fusion #1988)

* Mon May 28 2012 Paul Howarth <paul@city-fan.org> - 4.20-0.1.0.cf.beta3
- Update to 4.20 beta 3

* Thu May 17 2012 Paul Howarth <paul@city-fan.org> - 4.20-0.1.0.cf.beta2
- Update to 4.20 beta 2

* Thu May  3 2012 Paul Howarth <paul@city-fan.org> - 4.20-0.1.0.cf.beta1
- Update to 4.20 beta 1
- Update debian patch to 4.1.4-1

* Tue Jan 17 2012 Paul Howarth <paul@city-fan.org> - 4.10-1.0.cf
- Update to 4.10 final

* Mon Nov  7 2011 Paul Howarth <paul@city-fan.org> - 4.10-0.3.0.cf.beta3
- Update to 4.10 beta 3

* Thu Oct 20 2011 Paul Howarth <paul@city-fan.org> - 4.10-0.2.0.cf.beta2
- Update to 4.10 beta 2

* Tue Oct  4 2011 Paul Howarth <paul@city-fan.org> - 4.10-0.1.0.cf.beta1
- Update to 4.10 beta 1
- Fudge versions as tarball version number bears scant resemblance to the
  actual release version

* Mon Aug  1 2011 Paul Howarth <paul@city-fan.org> - 4.0-0.2.0.cf.beta7
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Mar  8 2011 Paul Howarth <paul@city-fan.org> - 4.0-0.1.0.cf.beta7
- Update to 4.0.7

* Mon Feb  7 2011 Paul Howarth <paul@city-fan.org> - 4.0-0.1.0.cf.beta6
- Update to 4.0.6 (GUI/archive maintenance fixes)

* Mon Jan 24 2011 Paul Howarth <paul@city-fan.org> - 4.0-0.1.0.cf.beta5
- Update to 4.0.5
  - Command line mode -ibck switch is applicable to most of archive processing
    operations, not just archiving and extracting
  - "a" and "s" commands with -iicon and -iimg switches did not remove
    temporary files after completion

* Wed Jan  5 2011 Paul Howarth <paul@city-fan.org> - 4.0-0.1.0.cf.beta4
- Update to 4.0.4
  - Previous beta versions could truncate some files extracted from ISO 9660
    archives
- Update debian patch to 4.0.3-1

* Mon Dec 20 2010 Paul Howarth <paul@city-fan.org> - 4.0-0.1.0.cf.beta3
- Update to 4.0.3
  - Now switch -ep3 converts not only disk letters, but also UNC paths, so
    \\server\share will be converted to __server\share when archiving and
    restored to the original \\server\share when extracting with -ep3
  - Previous beta could fail to unpack self-extracting and multivolume CAB
    archives
  - Previous beta crashed when displaying archive comments with ANSI escape
    sequences
  - Switches -cl and -cu did not work
- Update debian patch to 4.0.2-1

* Fri Nov 26 2010 Paul Howarth <paul@city-fan.org> - 4.0-0.1.0.cf.beta2
- Update to 4.0.2 (changes in GUI versions, unrar should be unchanged)

* Mon Nov 15 2010 Paul Howarth <paul@city-fan.org> - 4.0-0.1.0.cf.beta1
- Update to 4.0.1

* Fri Oct  1 2010 Paul Howarth <paul@city-fan.org> - 3.9.10-4.0.cf
- Rebuild for gcc bug (#634757)

* Wed Sep 29 2010 Paul Howarth <paul@city-fan.org> - 3.9.10-3.0.cf
- Resolve unresolved symbol issues noted in RPM Fusion Bug #1385

* Thu Sep  9 2010 Paul Howarth <paul@city-fan.org> - 3.9.10-2.1.cf
- Debian no longer patch the upstream sources and just have an additional
  tarball for the manpage etc. - update to version 3.9.10 of this

* Thu May 13 2010 Paul Howarth <paul@city-fan.org> - 3.9.10-2.0.cf
- Fix dist tag for RHEL-6 Beta

* Mon Mar 15 2010 Paul Howarth <paul@city-fan.org> - 3.9.10-1.0.cf
- Update to 3.9.10

* Mon Feb 15 2010 Paul Howarth <paul@city-fan.org> - 3.9.9-1.0.cf
- Update to 3.9.9

* Sun Jan 24 2010 Paul Howarth <paul@city-fan.org> - 3.9.8-1.0.cf
- Update to 3.9.8
- Update debian patch to 3.9.7-1

* Tue Dec 22 2009 Paul Howarth <paul@city-fan.org> - 3.9.7-1.0.cf
- Update to 3.9.7
- Update debian patch to 3.9.6-1
- Dist tag for Rawhide no longer needs special-casing

* Tue Oct 20 2009 Paul Howarth <paul@city-fan.org> - 3.9.6-1.0.cf
- Update to 3.9.6
- Make provide of libunrar3-%%{version} a versioned provide
- Make %%ghost-ed %%{_bindir}/unrar have exec bits set to placate rpmlint

* Wed Jul  8 2009 Paul Howarth <paul@city-fan.org> - 3.9.5-1.0.cf
- Update to 3.9.5
- Define RPM macros in global scope
- Mention that there are license limitations in the license tag
- Update URL to RAR-specific page
- Make package RPM Fusion compatible, i.e. include library packages, use
  alternatives

* Mon Sep 10 2007 Paul Howarth <paul@city-fan.org> - 3.7.8-1
- Update to 3.7.8

* Wed Sep  5 2007 Paul Howarth <paul@city-fan.org> - 3.7.7-1
- Update to 3.7.7

* Mon Aug 20 2007 Paul Howarth <paul@city-fan.org> - 3.7.6-1
- Update to 3.7.6

* Fri Mar  2 2007 Paul Howarth <paul@city-fan.org> - 3.7.4-1
- Update to 3.7.4

* Fri Feb  2 2007 Paul Howarth <paul@city-fan.org> - 3.7.3-1
- Update to 3.7.3
- Fix dist tag for Fedora test releases

* Fri Jan 12 2007 Paul Howarth <paul@city-fan.org> - 3.7.2-1
- Update to 3.7.2

* Wed Jan 10 2007 Paul Howarth <paul@city-fan.org> - 3.7.1-1
- Update to 3.7.1

* Wed Sep  6 2006 Paul Howarth <paul@city-fan.org> - 3.6.8-2
- Fix distribution tags for development releases

* Thu Aug 17 2006 Paul Howarth <paul@city-fan.org> - 3.6.8-1
- Update to 3.6.8

* Tue Aug  8 2006 Paul Howarth <paul@city-fan.org> - 3.6.7-1
- Update to 3.6.7
- Simplify distribution-detection
- Remove buildroot unconditionally in %%clean and %%install
- Remove basic reqs and buildreqs
- Fix rpmlint errors

* Tue Feb  1 2005 Paul Howarth <paul@city-fan.org> - 3.4.3-1
- Update to 3.4.3
- Auto-detect distribution for use in release tag

* Thu Feb 05 2004 Paul Howarth <paul@city-fan.org> - 3.3.4-1
- Build for Fedora Core 1

* Mon Jan 19 2004 Matthias Saou <http://freshrpms.net/> - 3.3.4-1.fr
- Update to 3.3.4

* Fri Nov  7 2003 Matthias Saou <http://freshrpms.net/> - 3.2.3-1.fr
- Update to 3.2.3
- Rebuild for Fedora Core 1

* Wed May 14 2003 Matthias Saou <matthias.saou@est.une.marmotte.net>
- Update to 3.2.1
- Added missing URL

* Mon Mar 31 2003 Matthias Saou <matthias.saou@est.une.marmotte.net>
- Update to 3.2.0
- Rebuilt for Red Hat Linux 9

* Mon Jan 13 2003 Matthias Saou <matthias.saou@est.une.marmotte.net>
- Update to 3.1.3

* Thu Oct 10 2002 Matthias Saou <matthias.saou@est.une.marmotte.net>
- Spec file cleanup

* Sat Oct  5 2002 Ville Skyttä <ville.skytta at iki.fi> - 3.00-2cr
- Rebuild for Red Hat 8.0, using the compat GCC

* Tue Sep 17 2002 Ville Skyttä <ville.skytta at iki.fi> - 3.00-1cr
- RedHatified PLD version

